<?php
/* ==================================================================
 *  custom-admin.php
 *  Function(s) to customize the admin view. 
 * ------------------------------------------------------------------
 *  author: Gabriel Nagmay <gabirel@nagmay.com>
 *  created: 	2010-02-09 
 *  updated: 	2010-06-24 Gabriel Nagmay -	Remove more meta for authors
 *											Remove that darn feature image
 *											Add Pending to editor dashboard.
 * ================================================================== */
     //retrieve current user info
     global $current_user, $menu;
     get_currentuserinfo();

/* === Customize Output === */
if( !is_admin()){
	wp_deregister_script('jquery'); // use pcc's (included in template)
}

/* === Customize Edit View === */
add_action('admin_init','customize_admin');

function customize_admin() {
     //retrieve current user info
     global $current_user, $menu;
     get_currentuserinfo();

     //if current user level is not admin level, remove the postcustom meta box
     if ($current_user->user_level < 10){	
	 	//remove_meta_box('slugdiv','post','normal'); // remove slug fields
		remove_meta_box('postcustom','post','normal'); // remove custom fields
		//remove_meta_box('trackbacksdiv','post','normal'); // remove trackbacks
		//remove_meta_box('commentstatusdiv','post','normal'); // remove discussion for now
		//remove_meta_box('commentsdiv','post','normal'); // remove comments for now
		
		unset($menu[10]); // remove Media menu
		unset($menu[15]); // remove Links menu
		//unset($menu[20]); // remove Pages Menu
		//unset($menu[25]); // remove Comments for now
	 }
	 
	 //if current user level is not editor level, remove more meta boxes
     if ($current_user->user_level < 7){	
		remove_meta_box('categorydiv','post','normal'); // remove categories
		remove_meta_box('tagsdiv-post_tag','post','normal'); // remove tags
	 }
	 
	 
}

/* === Remove Featured Image Meta === */
add_action('do_meta_boxes', 'remove_image_box');

function remove_image_box() {
	if ($current_user->user_level < 10){	
		remove_meta_box( 'postimagediv','post','side' );
	}
}


/* === Modify Dashboard === */

add_action('wp_dashboard_setup', 'my_custom_dashboard_widgets');

function my_custom_dashboard_widgets() {
   global $wp_meta_boxes;
   global $current_user;
   get_currentuserinfo();

   unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_plugins']);
   unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_primary']);
   unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_secondary']);
   unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_quick_press']);

   wp_add_dashboard_widget('custom_help_widget', 'Help and Support', 'custom_dashboard_help');
   if ($current_user->user_level >= 7){
		wp_add_dashboard_widget('custom_pending_widget', 'Pending', 'custom_pending');
   }
}

function custom_dashboard_help() {
   echo '<p>Welcome to the custom WordPress installation for <a href="/">'.get_bloginfo('name').'</a></p>';
   echo '<ul style="list-style-type:disc; margin-left:1.5em;">';
   echo '	<li>Need help? Contact the administrator: <a href="mailto:'.get_bloginfo('admin_email').'">'.get_bloginfo('admin_email').'</a></li>';
   echo '	<li>Detailed analytics can be viewed by logging into <a href="http://www.google.com/analytics/" target="_blank">www.google.com/analytics</a></li>';
   echo '</ul>';
} 

		/* Based on "Dashboard: Pending Review 2.0.0" by Viper007Bond */

function custom_pending() {	
		$pendings_query = new WP_Query( array(
			'post_type' => 'post',
			'what_to_show' => 'posts',
			'post_status' => 'pending',
			'posts_per_page' => 25,
			'orderby' => 'ID', // sort by order created, regardless of date
			'order' => 'DESC'
		) );
		$pendings =& $pendings_query->posts;

		if ( $pendings && is_array( $pendings ) ) {
			$list = array();
			foreach ( $pendings as $pending ) {
				$url = get_edit_post_link( $pending->ID );
				$title = _draft_or_post_title( $pending->ID );
				$item = "<h4><a href='$url' title='" . sprintf( __( 'Edit "%s"' ), attribute_escape( $title ) ) . "'>$title</a> ";
				//if ( $pending->au
				$item .= "<abbr title='" . get_the_time(__('Y/m/d g:i:s A'), $pending) . "'>" . get_the_time( get_option( 'date_format' ), $pending ) . '</abbr></h4>';
				if ( $the_content = preg_split( '#\s#', strip_tags( $pending->post_content ), 11, PREG_SPLIT_NO_EMPTY ) )
					$item .= '<p>' . join( ' ', array_slice( $the_content, 0, 10 ) ) . ( 10 < count( $the_content ) ? '&hellip;' : '' ) . '</p>';
				$list[] = $item;
			}

			echo "<ul>";
			echo "<li>".join( "</li>\n<li>", $list )."</li>";
			echo "</ul>";
			echo '<p class="textright"><a href="edit.php?post_status=pending" class="button">View all</a></p>';

		} else {
			echo'There are no pending posts at the moment';
		}


}







/* === Adds Custom META pannel "Custom Post Attributes" to Post/Page Edit === */

// define new custom meta (name, initial value, label title, description, tab index)
$custom_meta = array( 	"meta01" => array( "name" => "short-title", "value" => "", "title" => "Short Post Title", "tab" =>"3000"),
					 	"meta02" => array( "name" => "replace-byline", "value" => "", "title" => "Replace Byline", "tab" =>"3001"),
					  	"meta03" => array( "name" => "attach-feature-image", "value" => "", "title" => "Feature Image", "tab" =>"3003")
					);
function create_custom_meta(){
	global $theme_name;
	if ( function_exists('add_meta_box') ){
		//add_meta_box('custom-meta-box', 'Custom Post Attributes', 'custom_meta_box', 'post', 'normal', 'high');
	}
}
function custom_meta_box(){
	global $post, $custom_meta;
	$tab_index = 1000;
	foreach($custom_meta as &$meta){
		// is there a recorded value
		$meta_value = get_post_meta($post->ID, $meta['name'], true);
		if($meta_value != "") $meta['value'] = $meta_value;
		// set tab index
		if($meta[tab] == "") $meta['tab'] = $tab_index;
		$tab_index++;
	}
	
	// Create inputs
	echo'<p>Create short title to show on pcc.edu when <em>Homepage News</em> category is selected</p>';
	echo'<input type="hidden" name="'.$custom_meta['meta01']['name'].'_noncename" id="'.$custom_meta['meta01']['name'].'_noncename" value="'.wp_create_nonce( plugin_basename(__FILE__) ).'" />';
	echo'<p><label style="color:#777; width:100px; display:block; float:left; clear:left;" for="'.$custom_meta['meta01']['name'].'">'.$custom_meta['meta01']['title'].':</label>';
	echo'<input type="text" name="'.$custom_meta['meta01']['name'].'" value="'.$custom_meta['meta01']['value'].'" style="width:40%;" tabindex="'.$ustom_meta['meta01']['tab'].'" /></p>';
	
	echo'<br/><p>Multiple authors? This replaces: <em>Photos and Story by post author</em></p>';
	echo'<input type="hidden" name="'.$custom_meta['meta02']['name'].'_noncename" id="'.$custom_meta['meta02']['name'].'_noncename" value="'.wp_create_nonce( plugin_basename(__FILE__) ).'" />';
	echo'<p><label style="color:#777; width:100px; display:block; float:left; clear:left;" for="'.$custom_meta['meta02']['name'].'">'.$custom_meta['meta02']['title'].':</label>';
	echo'<input type="text" name="'.$custom_meta['meta02']['name'].'" value="'.$custom_meta['meta02']['value'].'" style="width:75%;" tabindex="'.$ustom_meta['meta02']['tab'].'" /></p>';
	
	echo'<br/><p>The src for the big image on pcc.edu when <em>Homepage Feature</em> is selected</p>';
	echo'<input type="hidden" name="'.$custom_meta['meta03']['name'].'_noncename" id="'.$custom_meta['meta03']['name'].'_noncename" value="'.wp_create_nonce( plugin_basename(__FILE__) ).'" />';
	echo'<p><label style="color:#777; width:100px; display:block; float:left; clear:left;" for="'.$custom_meta['meta03']['name'].'">'.$custom_meta['meta03']['title'].':</label>';
	echo'<input type="text" name="'.$custom_meta['meta03']['name'].'" value="'.$custom_meta['meta03']['value'].'" style="width:75%;" tabindex="'.$ustom_meta['meta03']['tab'].'" /></p>';
	
}
function save_custom_meta( $post_id ){
	global $post, $custom_meta;
	
	foreach($custom_meta as $meta){
		// Verify
		if ( !wp_verify_nonce( $_POST[$meta['name'].'_noncename'], plugin_basename(__FILE__) )){
			return $post_id;
		}
		if ( 'page' == $_POST['post_type'] ){
			if ( !current_user_can( 'edit_page', $post_id )) return $post_id;
		}
		else{
			if ( !current_user_can( 'edit_post', $post_id )) return $post_id;
		}
		
		$data = trim($_POST[$meta['name']]); // trim any leading ws
		
		if(get_post_meta($post_id, $meta['name']) == "") add_post_meta($post_id, $meta['name'], $data, true);
		elseif($data == "") delete_post_meta($post_id, $meta['name'], get_post_meta($post_id, $meta['name'], true));
		elseif($data != get_post_meta($post_id, $meta['name'], true)) update_post_meta($post_id, $meta['name'], $data);
		
	}
}
if ($current_user->user_level >= 7){
	/*
	add_action('admin_menu', 'create_custom_meta');
	add_action('save_post', 'save_custom_meta');
	*/
}



/* === Adds Custom META pannel "Facebook RSS" to Post/Page Edit === */

// define new custom meta (name, initial value, label title, description, tab index)
$fb_meta = array( 	"meta01" => array( "name" => "fb-title", "value" => "", "title" => "FB Post Title", "tab" =>"3004"),		
					"meta02" => array( "name" => "fb-excerpt", "value" => "", "title" => "FB Post Excerpt", "tab" =>"3005")	
					);
function create_fb_meta(){
	global $theme_name;
	if ( function_exists('add_meta_box') ){
		add_meta_box('fb-meta-box', 'FaceBook RSS', 'fb_meta_box', 'post', 'normal', 'high');
	}
}
function fb_meta_box(){
	global $post, $fb_meta;
	$tab_index = 1000;
	foreach($fb_meta as &$meta){
		// is there a recorded value
		$meta_value = get_post_meta($post->ID, $meta['name'], true);
		if($meta_value != "") $meta['value'] = $meta_value;
		// set tab index
		if($meta[tab] == "") $meta['tab'] = $tab_index;
		$tab_index++;
	}
	
	// Create inputs
	echo'<p>The following will overide the default title and excerpt for Facebook. <em>Facebook</em> category must be selected. View the <a href="http://news.pcc.edu/rss-fb/" target="_blank">fb feed</a>.</p>';
	echo'<input type="hidden" name="'.$fb_meta['meta01']['name'].'_noncename" id="'.$fb_meta['meta01']['name'].'_noncename" value="'.wp_create_nonce( plugin_basename(__FILE__) ).'" />';
	echo'<p><label style="color:#777; width:100px; display:block; float:left; clear:left;" for="'.$fb_meta['meta01']['name'].'">'.$fb_meta['meta01']['title'].':</label>';
	echo'<input type="text" name="'.$fb_meta['meta01']['name'].'" value="'.$fb_meta['meta01']['value'].'" style="width:40%;" tabindex="'.$ustom_meta['meta01']['tab'].'" /></p>';
	
	echo'<input type="hidden" name="'.$fb_meta['meta02']['name'].'_noncename" id="'.$fb_meta['meta02']['name'].'_noncename" value="'.wp_create_nonce( plugin_basename(__FILE__) ).'" />';
	echo'<p><label style="color:#777; width:100px; display:block; float:left; clear:left;" for="'.$fb_meta['meta02']['name'].'">'.$fb_meta['meta02']['title'].':</label>';
	echo'<textarea name="'.$fb_meta['meta02']['name'].'" style="width:75%;" tabindex="'.$ustom_meta['meta02']['tab'].'">'.$fb_meta['meta02']['value'].'</textarea></p>';
	
}
function save_fb_meta( $post_id ){
	global $post, $fb_meta;
	
	foreach($fb_meta as $meta){
		// Verify
		if ( !wp_verify_nonce( $_POST[$meta['name'].'_noncename'], plugin_basename(__FILE__) )){
			return $post_id;
		}
		if ( 'page' == $_POST['post_type'] ){
			if ( !current_user_can( 'edit_page', $post_id )) return $post_id;
		}
		else{
			if ( !current_user_can( 'edit_post', $post_id )) return $post_id;
		}
		
		$data = trim($_POST[$meta['name']]); // trim any leading ws
		
		if(get_post_meta($post_id, $meta['name']) == "") add_post_meta($post_id, $meta['name'], $data, true);
		elseif($data == "") delete_post_meta($post_id, $meta['name'], get_post_meta($post_id, $meta['name'], true));
		elseif($data != get_post_meta($post_id, $meta['name'], true)) update_post_meta($post_id, $meta['name'], $data);
		
	}
}
if ($current_user->user_level >= 7){
	/*
	add_action('admin_menu', 'create_fb_meta');
	add_action('save_post', 'save_fb_meta');*/
}


/* === Change MCE Editor  === */

function do_change_mce_buttons( $initArray ) {
	//@see http://wiki.moxiecode.com/index.php/TinyMCE:Control_reference
	$initArray['theme_advanced_blockformats'] = 'p,h3,h4,h5,h6,address,pre,code';
	$initArray['theme_advanced_disable'] = 'forecolor,indent,outdent,wp_help,wp_more';
	

	return $initArray;
}

add_filter('tiny_mce_before_init', 'do_change_mce_buttons');


?>